import { AsyncSelector, AsyncParams } from "shadow-dom-selector";
type HAQuerySelectorConfig = AsyncParams & {
    eventThreshold?: number;
};
type NodeDescriptorProps = {
    selector: string;
    children?: HomeAssistantNodeDescriptor;
};
type HomeAssistantNodeDescriptor = {
    [key: string]: NodeDescriptorProps;
};
type ElementProps = {
    element: Promise<Element | null>;
    children?: HomeAssistantElement;
    selector: AsyncSelector<Element>;
};
type HomeAssistantElement = {
    [key: string]: ElementProps;
};
type HAElement = Omit<ElementProps, "children">;
interface HAQuerySelectorEventListener<T> {
    (evt: CustomEvent<T>): void;
}
declare enum HA_ROOT_ELEMENT {
    HOME_ASSISTANT = "HOME_ASSISTANT",
    HOME_ASSISTANT_MAIN = "HOME_ASSISTANT_MAIN",
    HA_DRAWER = "HA_DRAWER",
    HA_SIDEBAR = "HA_SIDEBAR",
    PARTIAL_PANEL_RESOLVER = "PARTIAL_PANEL_RESOLVER"
}
declare enum HA_LOVELACE_ELEMENT {
    HA_PANEL_LOVELACE = "HA_PANEL_LOVELACE",
    HUI_ROOT = "HUI_ROOT",
    HEADER = "HEADER",
    HUI_VIEW = "HUI_VIEW"
}
declare enum HA_DIALOG_ELEMENT {
    HA_MORE_INFO_DIALOG = "HA_MORE_INFO_DIALOG",
    HA_DIALOG = "HA_DIALOG",
    HA_DIALOG_CONTENT = "HA_DIALOG_CONTENT",
    HA_MORE_INFO_DIALOG_INFO = "HA_MORE_INFO_DIALOG_INFO",
    HA_DIALOG_MORE_INFO_HISTORY_AND_LOGBOOK = "HA_DIALOG_MORE_INFO_HISTORY_AND_LOGBOOK",
    HA_DIALOG_MORE_INFO_SETTINGS = "HA_DIALOG_MORE_INFO_SETTINGS"
}
declare enum HAQuerySelectorEvent {
    ON_LISTEN = "onListen",
    ON_PANEL_LOAD = "onPanelLoad",
    ON_LOVELACE_PANEL_LOAD = "onLovelacePanelLoad",
    ON_MORE_INFO_DIALOG_OPEN = "onMoreInfoDialogOpen",
    ON_HISTORY_AND_LOGBOOK_DIALOG_OPEN = "onHistoryAndLogBookDialogOpen",
    ON_SETTINGS_DIALOG_OPEN = "onSettingsDialogOpen"
}
type OnListenDetail = Record<keyof typeof HA_ROOT_ELEMENT, HAElement>;
type OnPanelLoadDetail = Record<keyof typeof HA_ROOT_ELEMENT, HAElement>;
type OnLovelacePanelLoadDetail = Record<keyof typeof HA_ROOT_ELEMENT | keyof typeof HA_LOVELACE_ELEMENT, HAElement>;
type OnMoreInfoDialogOpenDetail = Record<Exclude<keyof typeof HA_DIALOG_ELEMENT, 'HA_DIALOG_MORE_INFO_HISTORY_AND_LOGBOOK' | 'HA_DIALOG_MORE_INFO_SETTINGS'>, HAElement>;
type OnHistoryAndLogBookDialogOpenDetail = Record<Exclude<keyof typeof HA_DIALOG_ELEMENT, 'HA_MORE_INFO_DIALOG_INFO' | 'HA_DIALOG_MORE_INFO_SETTINGS'>, HAElement>;
type OnSettingsDialogOpenDetail = Record<Exclude<keyof typeof HA_DIALOG_ELEMENT, 'HA_MORE_INFO_DIALOG_INFO' | 'HA_DIALOG_MORE_INFO_HISTORY_AND_LOGBOOK'>, HAElement>;
declare class DelegatedEventTarget implements EventTarget {
    private delegate;
    addEventListener(...args: Parameters<EventTarget['addEventListener']>): void;
    dispatchEvent(...args: Parameters<EventTarget['dispatchEvent']>): boolean;
    removeEventListener(...args: Parameters<EventTarget['removeEventListener']>): void;
}
declare class HAQuerySelector extends DelegatedEventTarget {
    constructor(config?: HAQuerySelectorConfig);
    private _config;
    private _dialogTree;
    private _homeAssistantRootTree;
    private _homeAssistantResolverTree;
    private _haDialogElements;
    private _haRootElements;
    private _haResolverElements;
    private _dialogsObserver;
    private _dialogsContentObserver;
    private _panelResolverObserver;
    private _lovelaceObserver;
    private _watchDialogsBinded;
    private _watchDialogsContentBinded;
    private _watchDashboardsBinded;
    private _watchLovelaceBinded;
    private _timestaps;
    private _dispatchEvent;
    private _updateDialogElements;
    private _updateRootElements;
    private _updateLovelaceElements;
    private _watchDialogs;
    private _watchDialogsContent;
    private _watchDashboards;
    private _watchLovelace;
    listen(): void;
    addEventListener(type: `${HAQuerySelectorEvent.ON_LISTEN}`, callback: HAQuerySelectorEventListener<OnListenDetail>, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: `${HAQuerySelectorEvent.ON_PANEL_LOAD}`, callback: HAQuerySelectorEventListener<OnPanelLoadDetail>, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: `${HAQuerySelectorEvent.ON_LOVELACE_PANEL_LOAD}`, callback: HAQuerySelectorEventListener<OnLovelacePanelLoadDetail>, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: `${HAQuerySelectorEvent.ON_MORE_INFO_DIALOG_OPEN}`, callback: HAQuerySelectorEventListener<OnMoreInfoDialogOpenDetail>, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: `${HAQuerySelectorEvent.ON_HISTORY_AND_LOGBOOK_DIALOG_OPEN}`, callback: HAQuerySelectorEventListener<OnHistoryAndLogBookDialogOpenDetail>, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: `${HAQuerySelectorEvent.ON_SETTINGS_DIALOG_OPEN}`, callback: HAQuerySelectorEventListener<OnSettingsDialogOpenDetail>, options?: boolean | AddEventListenerOptions): void;
}
export { HAQuerySelector, HAQuerySelectorEvent, HAElement, OnListenDetail, OnPanelLoadDetail, OnLovelacePanelLoadDetail, OnMoreInfoDialogOpenDetail, OnHistoryAndLogBookDialogOpenDetail, OnSettingsDialogOpenDetail };
